{% extends "base.html" %}{% comment %} -*- mode: django-html; tab-width: 4 -*- {% endcomment %}

{% block content %}
<div id="content">
  <div id="disclaimer">
Disclaimers:

<ul>

<li>This product uses the Flickr API but is not endorsed or certified by Flickr.
</li>

<li>All reference to Planning Districts on any maps or digital data
produced by the Office of Digital Cartography and GIS, Planning
Department, BRA are for planning purposes only and should NOT be
interpreted as official neighborhood boundaries for the City of
Boston. Thank you.
</li>

<li>Map icons courtesy
of <a href="http://mapicons.nicolasmollet.com">Maps Icons
Collection</a>, created by Nicolas Mollet under the Creative Commons
Attribution-Share Alike 3.0 Unported license (CC BY SA 3.0).
</li>

</ol>
  </div>
</div><!--/ #content -->
{% endblock %}
