{% extends "ebpub/templates/homepage.html" %}{% comment %} -*- mode: django-html; tab-width: 4 -*- {% endcomment %}


{% block fulltitle %}OpenBlock demo{% endblock %}

{% block extracontent %}
   <div id="homepage-about" class="sidebar-block">

   <h2>About OpenBlock</h2>

   <p>This is a public demo
   of <a href="http://openblockproject.org">OpenBlock</a>. It's
   still in the early stages, so expect to find bugs and see many
   under-designed pages. Feel free to kick the tires,
   and <a href="{% url accounts-register %}">register</a> if you feel like
   it. But be warned that we may reset the database at any time.
   We're <a href="http://blog.openblockproject.org">blogging about
   our progress</a>.
   </p>

   <p><a href="{% url obdemo-disclaimer %}">Disclaimers & Legal Notices</a>
   </p>

  </div>
{% endblock %}
